@@ -13,7 +13,6 @@ class ModelNet(Dataset):
     def __init__(
         self,
         root: Path,
-        num_classes: int,
         split: str,
         download: bool = False,
         transforms: List[Callable] = [],
@@ -21,8 +20,7 @@ class ModelNet(Dataset):
         """Create ModelNet dataset.
 
         Args:
-            root: The root that contains the directory "modelnet10" of "modelnet40.
-            num_classes: Either 10 or 40.
+            root: The directory that contains the dataset.
             split: The required split, it can be "train", "test" or "traintest".
             download: If True download the dataset using the "tmp" folder. Defaults to False.
             transforms: The list of transforms to apply to pcds. Defaults to [].
@@ -32,7 +30,7 @@ class ModelNet(Dataset):
         assert split in ["train", "test", "traintest"]
         self.split = split
 
-        self.dataset_root = root / f"modelnet{num_classes}"
+        self.dataset_root = root
 
         if download:
             if self.dataset_root.exists():
